@@ -12,7 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Utilities for choosing which member of a replica set to read from."""
+"""Utilities for choosing which member of a replica set to read from.
+
+.. seealso:: This module is compatible with both the synchronous and asynchronous PyMongo APIs.
+"""
 
 from __future__ import annotations
 
@@ -30,6 +33,7 @@ if TYPE_CHECKING:
     from pymongo.server_selectors import Selection
     from pymongo.topology_description import TopologyDescription
 
+
 _PRIMARY = 0
 _PRIMARY_PREFERRED = 1
 _SECONDARY = 2
@@ -603,10 +607,7 @@ class MovingAverage:
 
     def add_sample(self, sample: float) -> None:
         if sample < 0:
-            # Likely system time change while waiting for hello response
-            # and not using time.monotonic. Ignore it, the next one will
-            # probably be valid.
-            return
+            raise ValueError(f"duration cannot be negative {sample}")
         if self.average is None:
             self.average = sample
         else:
